@@ -75,9 +75,8 @@ my $configure_mysql=sub {
                        |_____/                            DATABASE
 END
    print $install_mysql;sleep 10;
-   ($stdout,$stderr)=$handle->cmd(
-      "sudo yum -y install mysql56",'__display__');
-      #"sudo yum groupinstall -y 'MySQL Database'",'__display__');
+   ($stdout,$stderr)=$handle->cmd("sudo yum -y install ".
+      "mysql56 mysql56-server mysql56-common mysql56-client",'__display__');
    ($stdout,$stderr)=$handle->cmd("sudo service mysqld start",
       '__display__');
    $handle->{_cmd_handle}->print('sudo mysql_secure_installation');
